#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optparse-simple
version:              0.1.1.4
visibility:           public
id:                   optparse-simple-0.1.1.4-GVDdiishQIyGTa9d3ZHvyy
key:                  optparse-simple-0.1.1.4-GVDdiishQIyGTa9d3ZHvyy
license:              BSD-3-Clause
copyright:            2015-2017 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               FP Complete
homepage:             https://github.com/fpco/optparse-simple#readme
synopsis:             Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>

category:             Options
abi:                  e497e6eed37ca1dad669eca1cf95b339
exposed:              True
exposed-modules:      Options.Applicative.Simple
hidden-modules:       Paths_optparse_simple
import-dirs:          /usr/lib/ghc-9.6.6/site-local/optparse-simple-0.1.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/optparse-simple-0.1.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/optparse-simple-0.1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optparse-simple
hs-libraries:         HSoptparse-simple-0.1.1.4-GVDdiishQIyGTa9d3ZHvyy
depends:
    base-4.18.2.1 githash-0.1.7.0-LCZwCOSUHSa2LjoI5e07WB
    optparse-applicative-0.18.1.0-8Us6opzobWeE8qMBykWiRI
    template-haskell-2.20.0.0 th-compat-0.1.7-4ztD20i2nFY3xRsDEetllT
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock

haddock-html:         /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

